pub async fn serialize(
sql: &str,
ctx: &SessionContext,
path: impl AsRef<Path>,
) -> Result<()>Expand description
Plans a sql and serializes the generated logical plan to bytes.
The bytes are then written into a file at path.
Returns an error if the file already exists.